@@ -28,7 +28,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = '2.07';
+    our $VERSION = '2.08';
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -784,4 +784,13 @@ This license includes the non-exclusive, worldwide, free-of-charge patent licens
 
 Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+=head1 B<TOOTING MY OWN HORN>
+
+Perl modules available on github - L<https://github.com/richcsst>
+
+And available on CPAN
+
+ *  Debug::Easy
+ *  Graphics::Framebuffer
+
 =cut
